"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class SalesRepResponse(object):
    """Implementation of the 'SalesRepResponse' model.

    This is the sales rep DTO

    Attributes:
        id (int): The unique Id of the sales rep
        first_name (str): The firstname of the sales rep
        last_name (str): The lastname of the sales rep
        sales_rep_numbers (List[int]): The sales rep Ids that are assigned to the rep

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "first_name": "FirstName",
        "last_name": "LastName",
        "sales_rep_numbers": "SalesRepNumbers",
    }

    _optionals = [
        "id",
        "first_name",
        "last_name",
        "sales_rep_numbers",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        first_name=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        sales_rep_numbers=APIHelper.SKIP):
        """Initialize a SalesRepResponse instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if sales_rep_numbers is not APIHelper.SKIP:
            self.sales_rep_numbers = sales_rep_numbers

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        sales_rep_numbers =\
            dictionary.get("SalesRepNumbers")\
            if dictionary.get("SalesRepNumbers")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   first_name,
                   last_name,
                   sales_rep_numbers)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _sales_rep_numbers=(
            self.sales_rep_numbers
            if hasattr(self, "sales_rep_numbers")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"first_name={_first_name!r}, "
            f"last_name={_last_name!r}, "
            f"sales_rep_numbers={_sales_rep_numbers!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _sales_rep_numbers=(
            self.sales_rep_numbers
            if hasattr(self, "sales_rep_numbers")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"first_name={_first_name!s}, "
            f"last_name={_last_name!s}, "
            f"sales_rep_numbers={_sales_rep_numbers!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.location import (
    Location,
)
from mindbodypublicapi.models.program import (
    Program,
)
from mindbodypublicapi.models.staff import Staff


class Course(object):
    """Implementation of the 'Course' model.

    A course.

    Attributes:
        id (int): The course ID.
        name (str): The course name.
        description (str): A description of the course.
        notes (str): Any notes that have been written about the course.
        start_date (datetime): Date and time that the course starts.
        end_date (datetime): Date and time that the course ends.
        location (Location): The model property of type Location.
        organizer (Staff): The Staff
        program (Program): The model property of type Program.
        image_url (str): The URL of the image associated with this course, if one
            exists.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "notes": "Notes",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "location": "Location",
        "organizer": "Organizer",
        "program": "Program",
        "image_url": "ImageUrl",
    }

    _optionals = [
        "id",
        "name",
        "description",
        "notes",
        "start_date",
        "end_date",
        "location",
        "organizer",
        "program",
        "image_url",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        description=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        location=APIHelper.SKIP,
        organizer=APIHelper.SKIP,
        program=APIHelper.SKIP,
        image_url=APIHelper.SKIP):
        """Initialize a Course instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if description is not APIHelper.SKIP:
            self.description = description
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if location is not APIHelper.SKIP:
            self.location = location
        if organizer is not APIHelper.SKIP:
            self.organizer = organizer
        if program is not APIHelper.SKIP:
            self.program = program
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        location =\
            Location.from_dictionary(
                dictionary.get("Location"))\
                if "Location" in dictionary.keys()\
                else APIHelper.SKIP
        organizer =\
            Staff.from_dictionary(
                dictionary.get("Organizer"))\
                if "Organizer" in dictionary.keys()\
                else APIHelper.SKIP
        program =\
            Program.from_dictionary(
                dictionary.get("Program"))\
                if "Program" in dictionary.keys()\
                else APIHelper.SKIP
        image_url =\
            dictionary.get("ImageUrl")\
            if dictionary.get("ImageUrl")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   description,
                   notes,
                   start_date,
                   end_date,
                   location,
                   organizer,
                   program,
                   image_url)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _organizer=(
            self.organizer
            if hasattr(self, "organizer")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"description={_description!r}, "
            f"notes={_notes!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"location={_location!r}, "
            f"organizer={_organizer!r}, "
            f"program={_program!r}, "
            f"image_url={_image_url!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _organizer=(
            self.organizer
            if hasattr(self, "organizer")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"description={_description!s}, "
            f"notes={_notes!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"location={_location!s}, "
            f"organizer={_organizer!s}, "
            f"program={_program!s}, "
            f"image_url={_image_url!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.class_client_detail import (
    ClassClientDetail,
)


class RemoveClientsFromClassesRequest(object):
    """Implementation of the 'RemoveClientsFromClassesRequest' model.

    Remove Clients From Classes Request

    Attributes:
        details (List[ClassClientDetail]): This object includes  `ClientIds`: List of
            the RSSID(string) of the clients to remove from the specified class.
            `ClassId`: The ID(number) of the class that you want to remove the
            clients from.
        test (bool): When `true`, the request ensures that its parameters are valid
            without affecting real data.<br />  When `false`, the request performs as
            intended and may affect live client data.<br />  Default: **false**
        send_email (bool): When `true`, indicates that the client should be sent an
            email. Depending on the site and client settings, an email may or may not
            be sent.<br />  Default: **false**  **Note**: When the Authorization
            header is passed and the SendEmail is set to `true`, then an email will
            be sent.  When the Authorization header is passed and the SendEmail is
            set to `false`, then an email will not be sent.  When the Authorization
            header is not passed and the SendEmail is set to either `true` or
            `false`, then an email will not be sent.
        late_cancel (bool): When `true`, indicates that the client is to be late
            cancelled from the class.<br />  When `false`, indicates that the client
            is to be early cancelled from the class.<br />  Default: **false**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "details": "Details",
        "test": "Test",
        "send_email": "SendEmail",
        "late_cancel": "LateCancel",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "details",
        "test",
        "send_email",
        "late_cancel",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        details=APIHelper.SKIP,
        test=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        late_cancel=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a RemoveClientsFromClassesRequest instance."""
        # Initialize members of the class
        if details is not APIHelper.SKIP:
            self.details = details
        if test is not APIHelper.SKIP:
            self.test = test
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        if late_cancel is not APIHelper.SKIP:
            self.late_cancel = late_cancel
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        details = None
        if dictionary.get("Details") is not None:
            details = [
                ClassClientDetail.from_dictionary(x)
                    for x in dictionary.get("Details")
            ]
        else:
            details = APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        late_cancel =\
            dictionary.get("LateCancel")\
            if "LateCancel" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(details,
                   test,
                   send_email,
                   late_cancel,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _details=(
            self.details
            if hasattr(self, "details")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _late_cancel=(
            self.late_cancel
            if hasattr(self, "late_cancel")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"details={_details!r}, "
            f"test={_test!r}, "
            f"send_email={_send_email!r}, "
            f"late_cancel={_late_cancel!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _details=(
            self.details
            if hasattr(self, "details")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _late_cancel=(
            self.late_cancel
            if hasattr(self, "late_cancel")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"details={_details!s}, "
            f"test={_test!s}, "
            f"send_email={_send_email!s}, "
            f"late_cancel={_late_cancel!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.spot import Spot


class Reservation(object):
    """Implementation of the 'Reservation' model.

    Contains information about the reservation.

    Attributes:
        reservation_id (str): The unique reservation ID.
        reservation_external_id (str): The unique reservation external ID.
        class_id (str): The unique class ID.
        class_external_id (str): The unique class external ID.
        member_external_id (str): The unique member external ID.
        reservation_type (str): Contains information about the reservation type.
        spots (Spot): Contains information about the spot details.
        is_confirmed (bool): Boolean value whether it is confirmed.
        confirmation_date (datetime): Contains information about the confirmation
            date.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reservation_id": "ReservationId",
        "reservation_external_id": "ReservationExternalId",
        "class_id": "ClassId",
        "class_external_id": "ClassExternalId",
        "member_external_id": "MemberExternalId",
        "reservation_type": "ReservationType",
        "spots": "Spots",
        "is_confirmed": "IsConfirmed",
        "confirmation_date": "ConfirmationDate",
    }

    _optionals = [
        "reservation_id",
        "reservation_external_id",
        "class_id",
        "class_external_id",
        "member_external_id",
        "reservation_type",
        "spots",
        "is_confirmed",
        "confirmation_date",
    ]

    def __init__(
        self,
        reservation_id=APIHelper.SKIP,
        reservation_external_id=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        class_external_id=APIHelper.SKIP,
        member_external_id=APIHelper.SKIP,
        reservation_type=APIHelper.SKIP,
        spots=APIHelper.SKIP,
        is_confirmed=APIHelper.SKIP,
        confirmation_date=APIHelper.SKIP):
        """Initialize a Reservation instance."""
        # Initialize members of the class
        if reservation_id is not APIHelper.SKIP:
            self.reservation_id = reservation_id
        if reservation_external_id is not APIHelper.SKIP:
            self.reservation_external_id = reservation_external_id
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if class_external_id is not APIHelper.SKIP:
            self.class_external_id = class_external_id
        if member_external_id is not APIHelper.SKIP:
            self.member_external_id = member_external_id
        if reservation_type is not APIHelper.SKIP:
            self.reservation_type = reservation_type
        if spots is not APIHelper.SKIP:
            self.spots = spots
        if is_confirmed is not APIHelper.SKIP:
            self.is_confirmed = is_confirmed
        if confirmation_date is not APIHelper.SKIP:
            self.confirmation_date =\
                 APIHelper.apply_datetime_converter(
                confirmation_date, APIHelper.RFC3339DateTime)\
                 if confirmation_date else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        reservation_id =\
            dictionary.get("ReservationId")\
            if dictionary.get("ReservationId")\
                else APIHelper.SKIP
        reservation_external_id =\
            dictionary.get("ReservationExternalId")\
            if dictionary.get("ReservationExternalId")\
                else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        class_external_id =\
            dictionary.get("ClassExternalId")\
            if dictionary.get("ClassExternalId")\
                else APIHelper.SKIP
        member_external_id =\
            dictionary.get("MemberExternalId")\
            if dictionary.get("MemberExternalId")\
                else APIHelper.SKIP
        reservation_type =\
            dictionary.get("ReservationType")\
            if dictionary.get("ReservationType")\
                else APIHelper.SKIP
        spots =\
            Spot.from_dictionary(
                dictionary.get("Spots"))\
                if "Spots" in dictionary.keys()\
                else APIHelper.SKIP
        is_confirmed =\
            dictionary.get("IsConfirmed")\
            if "IsConfirmed" in dictionary.keys()\
                else APIHelper.SKIP
        confirmation_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ConfirmationDate")).datetime\
            if dictionary.get("ConfirmationDate") else APIHelper.SKIP

        # Return an object of this model
        return cls(reservation_id,
                   reservation_external_id,
                   class_id,
                   class_external_id,
                   member_external_id,
                   reservation_type,
                   spots,
                   is_confirmed,
                   confirmation_date)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _reservation_id=(
            self.reservation_id
            if hasattr(self, "reservation_id")
            else None
        )
        _reservation_external_id=(
            self.reservation_external_id
            if hasattr(self, "reservation_external_id")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_external_id=(
            self.class_external_id
            if hasattr(self, "class_external_id")
            else None
        )
        _member_external_id=(
            self.member_external_id
            if hasattr(self, "member_external_id")
            else None
        )
        _reservation_type=(
            self.reservation_type
            if hasattr(self, "reservation_type")
            else None
        )
        _spots=(
            self.spots
            if hasattr(self, "spots")
            else None
        )
        _is_confirmed=(
            self.is_confirmed
            if hasattr(self, "is_confirmed")
            else None
        )
        _confirmation_date=(
            self.confirmation_date
            if hasattr(self, "confirmation_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reservation_id={_reservation_id!r}, "
            f"reservation_external_id={_reservation_external_id!r}, "
            f"class_id={_class_id!r}, "
            f"class_external_id={_class_external_id!r}, "
            f"member_external_id={_member_external_id!r}, "
            f"reservation_type={_reservation_type!r}, "
            f"spots={_spots!r}, "
            f"is_confirmed={_is_confirmed!r}, "
            f"confirmation_date={_confirmation_date!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _reservation_id=(
            self.reservation_id
            if hasattr(self, "reservation_id")
            else None
        )
        _reservation_external_id=(
            self.reservation_external_id
            if hasattr(self, "reservation_external_id")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_external_id=(
            self.class_external_id
            if hasattr(self, "class_external_id")
            else None
        )
        _member_external_id=(
            self.member_external_id
            if hasattr(self, "member_external_id")
            else None
        )
        _reservation_type=(
            self.reservation_type
            if hasattr(self, "reservation_type")
            else None
        )
        _spots=(
            self.spots
            if hasattr(self, "spots")
            else None
        )
        _is_confirmed=(
            self.is_confirmed
            if hasattr(self, "is_confirmed")
            else None
        )
        _confirmation_date=(
            self.confirmation_date
            if hasattr(self, "confirmation_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reservation_id={_reservation_id!s}, "
            f"reservation_external_id={_reservation_external_id!s}, "
            f"class_id={_class_id!s}, "
            f"class_external_id={_class_external_id!s}, "
            f"member_external_id={_member_external_id!s}, "
            f"reservation_type={_reservation_type!s}, "
            f"spots={_spots!s}, "
            f"is_confirmed={_is_confirmed!s}, "
            f"confirmation_date={_confirmation_date!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientDuplicatesRequest(object):
    """Implementation of the 'GetClientDuplicatesRequest' model.

    Attributes:
        first_name (str): The client first name to match on when searching for
            duplicates.
        last_name (str): The client last name to match on when searching for
            duplicates.
        email (str): The client email to match on when searching for duplicates.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "first_name": "FirstName",
        "last_name": "LastName",
        "email": "Email",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "first_name",
        "last_name",
        "email",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        first_name=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        email=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClientDuplicatesRequest instance."""
        # Initialize members of the class
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if email is not APIHelper.SKIP:
            self.email = email
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(first_name,
                   last_name,
                   email,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"first_name={_first_name!r}, "
            f"last_name={_last_name!r}, "
            f"email={_email!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"first_name={_first_name!s}, "
            f"last_name={_last_name!s}, "
            f"email={_email!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.applicable_item import (
    ApplicableItem,
)
from mindbodypublicapi.models.discount import (
    Discount,
)


class AddPromoCodeRequest(object):
    """Implementation of the 'AddPromoCodeRequest' model.

    Attributes:
        code (str): The code of the promocode.
        name (str): The name of the promocode.
        active (bool): Indicates that promocode is active. Default: **true**
        discount (Discount): Discount for a promo code
        activation_date (datetime): The date of the promocode activation. Default:
            **today’s date**
        expiration_date (datetime): The date of the promocode expiration. Default:
            **a months from today’s date**
        max_uses (int): The maximun number of uses. A use is considered a single sale.
        days_after_close_date (int): The number of days a client has to use a
            promocode after they are no longer a prospect.
        allow_online (bool): Indicates if promocode can be redeemed online in
            consumer mode. Default: **false**
        days_valid (List[str]): Indicates what days of the week promocode is valid.
            Defaults to 7 days of the week. Possible values are:  * Monday  * Tuesday
            * Wednesday  * Thursday  * Friday  * Saturday  * Sunday
        applicable_items (List[ApplicableItem]): Contains information about a
            promocode applicable items.  See ApplicableItems for a details of the
            `ApplicableItems` object.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code": "Code",
        "name": "Name",
        "active": "Active",
        "discount": "Discount",
        "activation_date": "ActivationDate",
        "expiration_date": "ExpirationDate",
        "max_uses": "MaxUses",
        "days_after_close_date": "DaysAfterCloseDate",
        "allow_online": "AllowOnline",
        "days_valid": "DaysValid",
        "applicable_items": "ApplicableItems",
    }

    _optionals = [
        "active",
        "discount",
        "activation_date",
        "expiration_date",
        "max_uses",
        "days_after_close_date",
        "allow_online",
        "days_valid",
        "applicable_items",
    ]

    def __init__(
        self,
        code=None,
        name=None,
        active=APIHelper.SKIP,
        discount=APIHelper.SKIP,
        activation_date=APIHelper.SKIP,
        expiration_date=APIHelper.SKIP,
        max_uses=APIHelper.SKIP,
        days_after_close_date=APIHelper.SKIP,
        allow_online=APIHelper.SKIP,
        days_valid=APIHelper.SKIP,
        applicable_items=APIHelper.SKIP):
        """Initialize a AddPromoCodeRequest instance."""
        # Initialize members of the class
        self.code = code
        self.name = name
        if active is not APIHelper.SKIP:
            self.active = active
        if discount is not APIHelper.SKIP:
            self.discount = discount
        if activation_date is not APIHelper.SKIP:
            self.activation_date =\
                 APIHelper.apply_datetime_converter(
                activation_date, APIHelper.RFC3339DateTime)\
                 if activation_date else None
        if expiration_date is not APIHelper.SKIP:
            self.expiration_date =\
                 APIHelper.apply_datetime_converter(
                expiration_date, APIHelper.RFC3339DateTime)\
                 if expiration_date else None
        if max_uses is not APIHelper.SKIP:
            self.max_uses = max_uses
        if days_after_close_date is not APIHelper.SKIP:
            self.days_after_close_date = days_after_close_date
        if allow_online is not APIHelper.SKIP:
            self.allow_online = allow_online
        if days_valid is not APIHelper.SKIP:
            self.days_valid = days_valid
        if applicable_items is not APIHelper.SKIP:
            self.applicable_items = applicable_items

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        code =\
            dictionary.get("Code")\
            if dictionary.get("Code")\
                else None
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else None
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        discount =\
            Discount.from_dictionary(
                dictionary.get("Discount"))\
                if "Discount" in dictionary.keys()\
                else APIHelper.SKIP
        activation_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActivationDate")).datetime\
            if dictionary.get("ActivationDate") else APIHelper.SKIP
        expiration_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ExpirationDate")).datetime\
            if dictionary.get("ExpirationDate") else APIHelper.SKIP
        max_uses =\
            dictionary.get("MaxUses")\
            if dictionary.get("MaxUses")\
                else APIHelper.SKIP
        days_after_close_date =\
            dictionary.get("DaysAfterCloseDate")\
            if dictionary.get("DaysAfterCloseDate")\
                else APIHelper.SKIP
        allow_online =\
            dictionary.get("AllowOnline")\
            if "AllowOnline" in dictionary.keys()\
                else APIHelper.SKIP
        days_valid =\
            dictionary.get("DaysValid")\
            if dictionary.get("DaysValid")\
                else APIHelper.SKIP
        applicable_items = None
        if dictionary.get("ApplicableItems") is not None:
            applicable_items = [
                ApplicableItem.from_dictionary(x)
                    for x in dictionary.get("ApplicableItems")
            ]
        else:
            applicable_items = APIHelper.SKIP

        # Return an object of this model
        return cls(code,
                   name,
                   active,
                   discount,
                   activation_date,
                   expiration_date,
                   max_uses,
                   days_after_close_date,
                   allow_online,
                   days_valid,
                   applicable_items)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _code=self.code
        _name=self.name
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _discount=(
            self.discount
            if hasattr(self, "discount")
            else None
        )
        _activation_date=(
            self.activation_date
            if hasattr(self, "activation_date")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _max_uses=(
            self.max_uses
            if hasattr(self, "max_uses")
            else None
        )
        _days_after_close_date=(
            self.days_after_close_date
            if hasattr(self, "days_after_close_date")
            else None
        )
        _allow_online=(
            self.allow_online
            if hasattr(self, "allow_online")
            else None
        )
        _days_valid=(
            self.days_valid
            if hasattr(self, "days_valid")
            else None
        )
        _applicable_items=(
            self.applicable_items
            if hasattr(self, "applicable_items")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"code={_code!r}, "
            f"name={_name!r}, "
            f"active={_active!r}, "
            f"discount={_discount!r}, "
            f"activation_date={_activation_date!r}, "
            f"expiration_date={_expiration_date!r}, "
            f"max_uses={_max_uses!r}, "
            f"days_after_close_date={_days_after_close_date!r}, "
            f"allow_online={_allow_online!r}, "
            f"days_valid={_days_valid!r}, "
            f"applicable_items={_applicable_items!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _code=self.code
        _name=self.name
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _discount=(
            self.discount
            if hasattr(self, "discount")
            else None
        )
        _activation_date=(
            self.activation_date
            if hasattr(self, "activation_date")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _max_uses=(
            self.max_uses
            if hasattr(self, "max_uses")
            else None
        )
        _days_after_close_date=(
            self.days_after_close_date
            if hasattr(self, "days_after_close_date")
            else None
        )
        _allow_online=(
            self.allow_online
            if hasattr(self, "allow_online")
            else None
        )
        _days_valid=(
            self.days_valid
            if hasattr(self, "days_valid")
            else None
        )
        _applicable_items=(
            self.applicable_items
            if hasattr(self, "applicable_items")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"code={_code!s}, "
            f"name={_name!s}, "
            f"active={_active!s}, "
            f"discount={_discount!s}, "
            f"activation_date={_activation_date!s}, "
            f"expiration_date={_expiration_date!s}, "
            f"max_uses={_max_uses!s}, "
            f"days_after_close_date={_days_after_close_date!s}, "
            f"allow_online={_allow_online!s}, "
            f"days_valid={_days_valid!s}, "
            f"applicable_items={_applicable_items!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientServicesRequest(object):
    """Implementation of the 'GetClientServicesRequest' model.

    Represents a request to retrieve client services with various filtering options.
    Note: if you want to request for a single client, use UniqueClientId or ClientId.
    For multiple clients, use UniqueClientIds or ClientIds.

    Attributes:
        client_id (str): The ID of the client to query. The results are a list of
            pricing options that the client has purchased. Note that “service” and
            “pricing option” are synonymous in this section of the documentation.
        unique_client_id (int): The unique ID of the client to query. Note that
            UniqueClientId takes precedence over ClientId.
        client_ids (List[str]): The IDs of the clients to query. The results are a
            list of pricing options that the clients have purchased.  ClientId
            parameter takes priority over ClientIds due to backward compatibility.
            So if you want to use ClientIds, then ClientId needs to be empty.  Either
            of ClientId or ClientIds need to be specified
        unique_client_ids (List[int]): The Unique IDs of the clients to query. Note
            that UniqueClientIds collection takes precedence over ClientIds
            collection.
        class_id (int): Filters results to only those pricing options that can be
            used to pay for this class.
        program_ids (List[int]): Filters results to pricing options that belong to
            one of the given program IDs.
        session_type_id (int): Filters results to pricing options that will pay for
            the given session type ID. Use this to find pricing options that will pay
            for a specific appointment type.
        location_ids (List[int]): Filters results to pricing options that can be used
            at the listed location IDs.
        visit_count (int): A filter on the minimum number of visits a service can pay
            for.
        start_date (datetime): Filters results to pricing options that are purchased
            on or after this date.  Default: **today’s date**
        end_date (datetime): Filters results to pricing options that are purchased on
            or before this date.   Default: **today’s date**
        show_active_only (bool): When `true`, includes active services only.
            Default: **false**
        cross_regional_lookup (bool): Used to retrieve a client’s pricing options
            from multiple sites within an organization. When included and set to
            `true`, it searches a maximum of ten sites with which this client is
            associated. When a client is associated with more than ten sites, use
            `ClientAssociatedSitesOffset` as many times as needed to search the
            additional sites with which the client is associated. You can use the
            `CrossRegionalClientAssociations` value from `GET
            CrossRegionalClientAssociations` to determine how many sites the client
            is associated with. Note that a `SiteID` is returned and populated in the
            `ClientServices` response when `CrossRegionalLookup` is set to `true`.
            Default: **false**
        ignore_cross_regional_site_limit (bool): Used to specify if the number of
            cross regional sites used to search for client’s pricing options should
            be ignored.   Default: **false**
        client_associated_sites_offset (int): Used to retrieve a client’s pricing
            options from multiple sites within an organization when the client is
            associated with more than ten sites. To change which ten sites are
            searched, change this offset value. A value of 0 means that no sites are
            skipped and the first ten sites are returned. You can use the
            `CrossRegionalClientAssociations` value from `GET
            CrossRegionalClientAssociations` to determine how many sites the client
            is associated with. Note that you must always have `CrossRegionalLookup`
            set to `true` to use this parameter.<br />  Default: **0**    For
            example, if a client is associated with 25 sites, you need to call
            `GetClientServices` three times, as follows:  * Use `GET
            CrossRegionalClientAssociations` to determine how many sites a client is
            associated with, which tells you how many additional calls you need to
            make.  * Either omit `ClientAssociatedSitesOffset` or set it to 0 to
            return the client’s services (pricing options) from sites 1-10.  * Set
            `ClientAssociatedSitesOffset` to 10 to return the client pricing options
            from sites 11-20  * Set `ClientAssociatedSitesOffset` to 20 to return the
            client pricing options from sites 21-25
        exclude_inactive_sites (bool): When this flag is set to `true`, will exclude
            inactive sites from the response.  Default: **false**
        use_activate_date (bool): When this flag is set to `true`, the date filtering
            will use activate date to filter the pricing options.  When this flag is
            set to `false`, the date filtering will use purchase date to filter the
            pricing options.  Default: **false**
        class_schedule_id (List[int]): Filters results to pricing options which are
            associated with one of the ClassScheduleIDs
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "client_ids": "ClientIds",
        "unique_client_ids": "UniqueClientIds",
        "class_id": "ClassId",
        "program_ids": "ProgramIds",
        "session_type_id": "SessionTypeId",
        "location_ids": "LocationIds",
        "visit_count": "VisitCount",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "show_active_only": "ShowActiveOnly",
        "cross_regional_lookup": "CrossRegionalLookup",
        "ignore_cross_regional_site_limit": "IgnoreCrossRegionalSiteLimit",
        "client_associated_sites_offset": "ClientAssociatedSitesOffset",
        "exclude_inactive_sites": "ExcludeInactiveSites",
        "use_activate_date": "UseActivateDate",
        "class_schedule_id": "ClassScheduleID",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "client_id",
        "unique_client_id",
        "client_ids",
        "unique_client_ids",
        "class_id",
        "program_ids",
        "session_type_id",
        "location_ids",
        "visit_count",
        "start_date",
        "end_date",
        "show_active_only",
        "cross_regional_lookup",
        "ignore_cross_regional_site_limit",
        "client_associated_sites_offset",
        "exclude_inactive_sites",
        "use_activate_date",
        "class_schedule_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        client_ids=APIHelper.SKIP,
        unique_client_ids=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        location_ids=APIHelper.SKIP,
        visit_count=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        show_active_only=APIHelper.SKIP,
        cross_regional_lookup=APIHelper.SKIP,
        ignore_cross_regional_site_limit=APIHelper.SKIP,
        client_associated_sites_offset=APIHelper.SKIP,
        exclude_inactive_sites=APIHelper.SKIP,
        use_activate_date=APIHelper.SKIP,
        class_schedule_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClientServicesRequest instance."""
        # Initialize members of the class
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if client_ids is not APIHelper.SKIP:
            self.client_ids = client_ids
        if unique_client_ids is not APIHelper.SKIP:
            self.unique_client_ids = unique_client_ids
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if visit_count is not APIHelper.SKIP:
            self.visit_count = visit_count
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if show_active_only is not APIHelper.SKIP:
            self.show_active_only = show_active_only
        if cross_regional_lookup is not APIHelper.SKIP:
            self.cross_regional_lookup = cross_regional_lookup
        if ignore_cross_regional_site_limit is not APIHelper.SKIP:
            self.ignore_cross_regional_site_limit = ignore_cross_regional_site_limit
        if client_associated_sites_offset is not APIHelper.SKIP:
            self.client_associated_sites_offset = client_associated_sites_offset
        if exclude_inactive_sites is not APIHelper.SKIP:
            self.exclude_inactive_sites = exclude_inactive_sites
        if use_activate_date is not APIHelper.SKIP:
            self.use_activate_date = use_activate_date
        if class_schedule_id is not APIHelper.SKIP:
            self.class_schedule_id = class_schedule_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        client_ids =\
            dictionary.get("ClientIds")\
            if dictionary.get("ClientIds")\
                else APIHelper.SKIP
        unique_client_ids =\
            dictionary.get("UniqueClientIds")\
            if dictionary.get("UniqueClientIds")\
                else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        visit_count =\
            dictionary.get("VisitCount")\
            if dictionary.get("VisitCount")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        show_active_only =\
            dictionary.get("ShowActiveOnly")\
            if "ShowActiveOnly" in dictionary.keys()\
                else APIHelper.SKIP
        cross_regional_lookup =\
            dictionary.get("CrossRegionalLookup")\
            if "CrossRegionalLookup" in dictionary.keys()\
                else APIHelper.SKIP
        ignore_cross_regional_site_limit =\
            dictionary.get("IgnoreCrossRegionalSiteLimit")\
            if "IgnoreCrossRegionalSiteLimit" in dictionary.keys()\
                else APIHelper.SKIP
        client_associated_sites_offset =\
            dictionary.get("ClientAssociatedSitesOffset")\
            if dictionary.get("ClientAssociatedSitesOffset")\
                else APIHelper.SKIP
        exclude_inactive_sites =\
            dictionary.get("ExcludeInactiveSites")\
            if "ExcludeInactiveSites" in dictionary.keys()\
                else APIHelper.SKIP
        use_activate_date =\
            dictionary.get("UseActivateDate")\
            if "UseActivateDate" in dictionary.keys()\
                else APIHelper.SKIP
        class_schedule_id =\
            dictionary.get("ClassScheduleID")\
            if dictionary.get("ClassScheduleID")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   unique_client_id,
                   client_ids,
                   unique_client_ids,
                   class_id,
                   program_ids,
                   session_type_id,
                   location_ids,
                   visit_count,
                   start_date,
                   end_date,
                   show_active_only,
                   cross_regional_lookup,
                   ignore_cross_regional_site_limit,
                   client_associated_sites_offset,
                   exclude_inactive_sites,
                   use_activate_date,
                   class_schedule_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _client_ids=(
            self.client_ids
            if hasattr(self, "client_ids")
            else None
        )
        _unique_client_ids=(
            self.unique_client_ids
            if hasattr(self, "unique_client_ids")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _visit_count=(
            self.visit_count
            if hasattr(self, "visit_count")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _show_active_only=(
            self.show_active_only
            if hasattr(self, "show_active_only")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _ignore_cross_regional_site_limit=(
            self.ignore_cross_regional_site_limit
            if hasattr(self, "ignore_cross_regional_site_limit")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _exclude_inactive_sites=(
            self.exclude_inactive_sites
            if hasattr(self, "exclude_inactive_sites")
            else None
        )
        _use_activate_date=(
            self.use_activate_date
            if hasattr(self, "use_activate_date")
            else None
        )
        _class_schedule_id=(
            self.class_schedule_id
            if hasattr(self, "class_schedule_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"client_ids={_client_ids!r}, "
            f"unique_client_ids={_unique_client_ids!r}, "
            f"class_id={_class_id!r}, "
            f"program_ids={_program_ids!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"location_ids={_location_ids!r}, "
            f"visit_count={_visit_count!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"show_active_only={_show_active_only!r}, "
            f"cross_regional_lookup={_cross_regional_lookup!r}, "
            f"ignore_cross_regional_site_limit={_ignore_cross_regional_site_limit!r}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!r}, "
            f"exclude_inactive_sites={_exclude_inactive_sites!r}, "
            f"use_activate_date={_use_activate_date!r}, "
            f"class_schedule_id={_class_schedule_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _client_ids=(
            self.client_ids
            if hasattr(self, "client_ids")
            else None
        )
        _unique_client_ids=(
            self.unique_client_ids
            if hasattr(self, "unique_client_ids")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _visit_count=(
            self.visit_count
            if hasattr(self, "visit_count")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _show_active_only=(
            self.show_active_only
            if hasattr(self, "show_active_only")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _ignore_cross_regional_site_limit=(
            self.ignore_cross_regional_site_limit
            if hasattr(self, "ignore_cross_regional_site_limit")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _exclude_inactive_sites=(
            self.exclude_inactive_sites
            if hasattr(self, "exclude_inactive_sites")
            else None
        )
        _use_activate_date=(
            self.use_activate_date
            if hasattr(self, "use_activate_date")
            else None
        )
        _class_schedule_id=(
            self.class_schedule_id
            if hasattr(self, "class_schedule_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"client_ids={_client_ids!s}, "
            f"unique_client_ids={_unique_client_ids!s}, "
            f"class_id={_class_id!s}, "
            f"program_ids={_program_ids!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"location_ids={_location_ids!s}, "
            f"visit_count={_visit_count!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"show_active_only={_show_active_only!s}, "
            f"cross_regional_lookup={_cross_regional_lookup!s}, "
            f"ignore_cross_regional_site_limit={_ignore_cross_regional_site_limit!s}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!s}, "
            f"exclude_inactive_sites={_exclude_inactive_sites!s}, "
            f"use_activate_date={_use_activate_date!s}, "
            f"class_schedule_id={_class_schedule_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddStaffAvailabilityRequest(object):
    """Implementation of the 'AddStaffAvailabilityRequest' model.

    Add Staff Availability/Unavailability Schedule

    Attributes:
        staff_id (int): The ID of the staff member that availability or
            unavailability will be added.
        is_availability (bool): When `true`, indicates that availability will be
            added, <br />  When `false`, indicates that unavailability will be added.
        description (str): The description of the unavailability, ex. Lunch,
            Vacation. Required if IsAvailability passed as `false`.  Omit if
            IsAvailability passed as `true`.
        program_ids (List[int]): A list of program IDs. Must be a valid active
            schedulable Program ID. Required if IsAvailability passed as `true`.
            Omit if IsAvailability passed as `false`.
        location_id (int): The ID of the location where the availability is added.
            Required if IsAvailability passed as `true`.  Omit if IsAvailability
            passed as `false`.
        days_of_week (List[str]): The days of the week. Must contain at least one of
            the following Sunday, Monday, Tuesday etc.
        start_time (str): The start time of the schedule. Must be in HH:MM:SS format.
        end_time (str): The end time of the schedule. Must be in HH:MM:SS format.
        start_date (str): The start date of the schedule. Must be in YYYY-MM-DD
            format.
        end_date (str): The end date of the schedule. Must be in YYYY-MM-DD format.
        status (str): The status of availability or unavailability. Possible values
            are:  * Masked  * Hidden  * Public    Default: Public

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "is_availability": "IsAvailability",
        "days_of_week": "DaysOfWeek",
        "start_time": "StartTime",
        "end_time": "EndTime",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "description": "Description",
        "program_ids": "ProgramIds",
        "location_id": "LocationId",
        "status": "Status",
    }

    _optionals = [
        "description",
        "program_ids",
        "location_id",
        "status",
    ]

    def __init__(
        self,
        staff_id=None,
        is_availability=None,
        days_of_week=None,
        start_time=None,
        end_time=None,
        start_date=None,
        end_date=None,
        description=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        status=APIHelper.SKIP):
        """Initialize a AddStaffAvailabilityRequest instance."""
        # Initialize members of the class
        self.staff_id = staff_id
        self.is_availability = is_availability
        if description is not APIHelper.SKIP:
            self.description = description
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        self.days_of_week = days_of_week
        self.start_time = start_time
        self.end_time = end_time
        self.start_date = start_date
        self.end_date = end_date
        if status is not APIHelper.SKIP:
            self.status = status

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else None
        is_availability =\
            dictionary.get("IsAvailability")\
            if "IsAvailability" in dictionary.keys()\
                else None
        days_of_week =\
            dictionary.get("DaysOfWeek")\
            if dictionary.get("DaysOfWeek")\
                else None
        start_time =\
            dictionary.get("StartTime")\
            if dictionary.get("StartTime")\
                else None
        end_time =\
            dictionary.get("EndTime")\
            if dictionary.get("EndTime")\
                else None
        start_date =\
            dictionary.get("StartDate")\
            if dictionary.get("StartDate")\
                else None
        end_date =\
            dictionary.get("EndDate")\
            if dictionary.get("EndDate")\
                else None
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        status =\
            dictionary.get("Status")\
            if dictionary.get("Status")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   is_availability,
                   days_of_week,
                   start_time,
                   end_time,
                   start_date,
                   end_date,
                   description,
                   program_ids,
                   location_id,
                   status)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=self.staff_id
        _is_availability=self.is_availability
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _days_of_week=self.days_of_week
        _start_time=self.start_time
        _end_time=self.end_time
        _start_date=self.start_date
        _end_date=self.end_date
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"is_availability={_is_availability!r}, "
            f"description={_description!r}, "
            f"program_ids={_program_ids!r}, "
            f"location_id={_location_id!r}, "
            f"days_of_week={_days_of_week!r}, "
            f"start_time={_start_time!r}, "
            f"end_time={_end_time!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"status={_status!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=self.staff_id
        _is_availability=self.is_availability
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _days_of_week=self.days_of_week
        _start_time=self.start_time
        _end_time=self.end_time
        _start_date=self.start_date
        _end_date=self.end_date
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"is_availability={_is_availability!s}, "
            f"description={_description!s}, "
            f"program_ids={_program_ids!s}, "
            f"location_id={_location_id!s}, "
            f"days_of_week={_days_of_week!s}, "
            f"start_time={_start_time!s}, "
            f"end_time={_end_time!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"status={_status!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateAvailabilityRequest(object):
    """Implementation of the 'UpdateAvailabilityRequest' model.

    This is the update avaialability request coming DTO

    Attributes:
        availability_ids (List[int]): Unique IDs for the availabilities or
            unavailabilities.
        public_display (PublicDisplayEnum): Choice that decides whether the
            availablity should be publicly visible, masked or hidden.
        days_of_week (List[DaysOfWeekEnum]): The days of week to update the
            availabilities or unavailabilities.<br />  Default: **All**
        program_ids (List[int]): The program Id to be set for the availabilities.
            Default: **All**
        start_date_time (datetime): The start date and time for the availabilities or
            unavailabilities.
        end_date_time (datetime): The end date and time for the availabilities or
            unavailabilities.
        location_id (int): The location Id to be updated for the provided
            availability Ids.
        unavailable_description (str): The description for unavailability.
        test (bool): When `true`, the request ensures that its parameters are valid
            without affecting real data.  When ``false`, the request performs as
            intended and may affect live client data.  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "availability_ids": "AvailabilityIds",
        "public_display": "PublicDisplay",
        "days_of_week": "DaysOfWeek",
        "program_ids": "ProgramIds",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "location_id": "LocationId",
        "unavailable_description": "UnavailableDescription",
        "test": "Test",
    }

    _optionals = [
        "availability_ids",
        "public_display",
        "days_of_week",
        "program_ids",
        "start_date_time",
        "end_date_time",
        "location_id",
        "unavailable_description",
        "test",
    ]

    def __init__(
        self,
        availability_ids=APIHelper.SKIP,
        public_display=APIHelper.SKIP,
        days_of_week=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        unavailable_description=APIHelper.SKIP,
        test=APIHelper.SKIP):
        """Initialize a UpdateAvailabilityRequest instance."""
        # Initialize members of the class
        if availability_ids is not APIHelper.SKIP:
            self.availability_ids = availability_ids
        if public_display is not APIHelper.SKIP:
            self.public_display = public_display
        if days_of_week is not APIHelper.SKIP:
            self.days_of_week = days_of_week
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if unavailable_description is not APIHelper.SKIP:
            self.unavailable_description = unavailable_description
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        availability_ids =\
            dictionary.get("AvailabilityIds")\
            if dictionary.get("AvailabilityIds")\
                else APIHelper.SKIP
        public_display =\
            dictionary.get("PublicDisplay")\
            if dictionary.get("PublicDisplay")\
                else APIHelper.SKIP
        days_of_week =\
            dictionary.get("DaysOfWeek")\
            if dictionary.get("DaysOfWeek")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        unavailable_description =\
            dictionary.get("UnavailableDescription")\
            if dictionary.get("UnavailableDescription")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(availability_ids,
                   public_display,
                   days_of_week,
                   program_ids,
                   start_date_time,
                   end_date_time,
                   location_id,
                   unavailable_description,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _availability_ids=(
            self.availability_ids
            if hasattr(self, "availability_ids")
            else None
        )
        _public_display=(
            self.public_display
            if hasattr(self, "public_display")
            else None
        )
        _days_of_week=(
            self.days_of_week
            if hasattr(self, "days_of_week")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _unavailable_description=(
            self.unavailable_description
            if hasattr(self, "unavailable_description")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"availability_ids={_availability_ids!r}, "
            f"public_display={_public_display!r}, "
            f"days_of_week={_days_of_week!r}, "
            f"program_ids={_program_ids!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"location_id={_location_id!r}, "
            f"unavailable_description={_unavailable_description!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _availability_ids=(
            self.availability_ids
            if hasattr(self, "availability_ids")
            else None
        )
        _public_display=(
            self.public_display
            if hasattr(self, "public_display")
            else None
        )
        _days_of_week=(
            self.days_of_week
            if hasattr(self, "days_of_week")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _unavailable_description=(
            self.unavailable_description
            if hasattr(self, "unavailable_description")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"availability_ids={_availability_ids!s}, "
            f"public_display={_public_display!s}, "
            f"days_of_week={_days_of_week!s}, "
            f"program_ids={_program_ids!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"location_id={_location_id!s}, "
            f"unavailable_description={_unavailable_description!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.promo_code import (
    PromoCode,
)


class AddPromoCodeResponse(object):
    """Implementation of the 'AddPromoCodeResponse' model.

    Attributes:
        promo_code (PromoCode): The model property of type PromoCode.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "promo_code": "PromoCode",
    }

    _optionals = [
        "promo_code",
    ]

    def __init__(
        self,
        promo_code=APIHelper.SKIP):
        """Initialize a AddPromoCodeResponse instance."""
        # Initialize members of the class
        if promo_code is not APIHelper.SKIP:
            self.promo_code = promo_code

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        promo_code =\
            PromoCode.from_dictionary(
                dictionary.get("PromoCode"))\
                if "PromoCode" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(promo_code)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _promo_code=(
            self.promo_code
            if hasattr(self, "promo_code")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"promo_code={_promo_code!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _promo_code=(
            self.promo_code
            if hasattr(self, "promo_code")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"promo_code={_promo_code!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.issue_response import (
    IssueResponse,
)


class UserTokenController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize UserTokenController object."""
        super(UserTokenController, self).__init__(config)

    def issue_token(self,
                    version,
                    request,
                    site_id):
        """Perform a POST request to /public/v{version}/usertoken/issue.

        When users interact with your Public API integration as staff members, they
        need to get a staff user token for authentication.
        You can use the issue endpoint to get a staff user token, then pass the token
        in the headers for all of your requests.

        Args:
            version (str): version of the api.
            request (IssueRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.

        Returns:
            IssueResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/usertoken/issue")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(IssueResponse.from_dictionary),
        ).execute()

    def renew_token(self,
                    version,
                    site_id,
                    authorization=None):
        """Perform a POST request to /public/v{version}/usertoken/renew.

        Renews a token. Can be used to extend the lifetime of a token.
        Current lifetime expansion: 24hrs from current expiration, up to 7 renewals.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            Any: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/usertoken/renew")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize),
        ).execute()

    def revoke_token(self,
                     version,
                     site_id,
                     authorization=None):
        """Perform a DELETE request to /public/v{version}/usertoken/revoke.

        Revokes the user token in the Authorization header.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            Any: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/usertoken/revoke")
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ReturnSaleRequest(object):
    """Implementation of the 'ReturnSaleRequest' model.

    ReturnSaleRequest

    Attributes:
        sale_id (int): The Sale ID of the sale item to be returned.
        return_reason (str): The reason for the return.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sale_id": "SaleId",
        "return_reason": "ReturnReason",
    }

    _optionals = [
        "sale_id",
        "return_reason",
    ]

    def __init__(
        self,
        sale_id=APIHelper.SKIP,
        return_reason=APIHelper.SKIP):
        """Initialize a ReturnSaleRequest instance."""
        # Initialize members of the class
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if return_reason is not APIHelper.SKIP:
            self.return_reason = return_reason

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        return_reason =\
            dictionary.get("ReturnReason")\
            if dictionary.get("ReturnReason")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(sale_id,
                   return_reason)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _return_reason=(
            self.return_reason
            if hasattr(self, "return_reason")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_id={_sale_id!r}, "
            f"return_reason={_return_reason!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _return_reason=(
            self.return_reason
            if hasattr(self, "return_reason")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_id={_sale_id!s}, "
            f"return_reason={_return_reason!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""


class APIException(Exception):
    """Class that handles HTTP Exceptions when fetching API Endpoints.

    Attributes:
        response_code (int): The status code of the response.
        response (HttpResponse): The HttpResponse of the API call.

    """

    def __init__(self,
                 reason,
                 response):
        """Initialize APIException object.

        Args:
            reason (string): The reason (or error message) for the Exception
                to be raised.
            response (HttpResponse): The HttpResponse of the API call.

        """
        super(APIException, self).__init__(reason)
        self.reason = reason
        self.response = response
        self.response_code = response.status_code

    def __str__(self):
        """Return a human-readable string representation."""
        return (f"{self.__class__.__name__}("
                f"status_code={self.response_code!s}, "
                f"message={self.reason!s})")



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ClientDuplicate(object):
    """Implementation of the 'ClientDuplicate' model.

    A client record that is considered a duplicate based on matching of the client's
    first name, last name, AND email fields

    Attributes:
        id (str): The client’s ID, as configured by the business owner. This is the
            client’s barcode ID if the business owner assigns barcodes to clients.
            This ID is used throughout the Public API for client-related Public API
            calls. When used in a POST `UpdateClient` request, the `Id` is used to
            identify the client for the update.
        unique_id (int): The client’s system-generated ID at the business. This value
            cannot be changed by business owners and is always unique across all
            clients at the business. This ID is not widely used in the Public API,
            but can be used by your application to uniquely identify clients.
        first_name (str): The client’s first name.
        last_name (str): The client’s last name.
        email (str): The client’s email address.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "unique_id": "UniqueId",
        "first_name": "FirstName",
        "last_name": "LastName",
        "email": "Email",
    }

    _optionals = [
        "id",
        "unique_id",
        "first_name",
        "last_name",
        "email",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        unique_id=APIHelper.SKIP,
        first_name=APIHelper.SKIP,
        last_name=APIHelper.SKIP,
        email=APIHelper.SKIP):
        """Initialize a ClientDuplicate instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if unique_id is not APIHelper.SKIP:
            self.unique_id = unique_id
        if first_name is not APIHelper.SKIP:
            self.first_name = first_name
        if last_name is not APIHelper.SKIP:
            self.last_name = last_name
        if email is not APIHelper.SKIP:
            self.email = email

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        unique_id =\
            dictionary.get("UniqueId")\
            if dictionary.get("UniqueId")\
                else APIHelper.SKIP
        first_name =\
            dictionary.get("FirstName")\
            if dictionary.get("FirstName")\
                else APIHelper.SKIP
        last_name =\
            dictionary.get("LastName")\
            if dictionary.get("LastName")\
                else APIHelper.SKIP
        email =\
            dictionary.get("Email")\
            if dictionary.get("Email")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   unique_id,
                   first_name,
                   last_name,
                   email)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _unique_id=(
            self.unique_id
            if hasattr(self, "unique_id")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"unique_id={_unique_id!r}, "
            f"first_name={_first_name!r}, "
            f"last_name={_last_name!r}, "
            f"email={_email!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _unique_id=(
            self.unique_id
            if hasattr(self, "unique_id")
            else None
        )
        _first_name=(
            self.first_name
            if hasattr(self, "first_name")
            else None
        )
        _last_name=(
            self.last_name
            if hasattr(self, "last_name")
            else None
        )
        _email=(
            self.email
            if hasattr(self, "email")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"unique_id={_unique_id!s}, "
            f"first_name={_first_name!s}, "
            f"last_name={_last_name!s}, "
            f"email={_email!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.client import (
    Client,
)


class AddClientResponse(object):
    """Implementation of the 'AddClientResponse' model.

    Attributes:
        client (Client): The Client.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client": "Client",
    }

    _optionals = [
        "client",
    ]

    def __init__(
        self,
        client=APIHelper.SKIP):
        """Initialize a AddClientResponse instance."""
        # Initialize members of the class
        if client is not APIHelper.SKIP:
            self.client = client

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client =\
            Client.from_dictionary(
                dictionary.get("Client"))\
                if "Client" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client=(
            self.client
            if hasattr(self, "client")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client={_client!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client=(
            self.client
            if hasattr(self, "client")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client={_client!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddFormulaNoteRequest(object):
    """Implementation of the 'AddFormulaNoteRequest' model.

    Attributes:
        client_id (str): The ID of the client who needs to have a formula note added.
        appointment_id (int): The appointment ID that the formula note is related to.
        note (str): The new formula note text.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "note": "Note",
        "appointment_id": "AppointmentId",
    }

    _optionals = [
        "appointment_id",
    ]

    def __init__(
        self,
        client_id=None,
        note=None,
        appointment_id=APIHelper.SKIP):
        """Initialize a AddFormulaNoteRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        if appointment_id is not APIHelper.SKIP:
            self.appointment_id = appointment_id
        self.note = note

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        note =\
            dictionary.get("Note")\
            if dictionary.get("Note")\
                else None
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   note,
                   appointment_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _note=self.note
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"appointment_id={_appointment_id!r}, "
            f"note={_note!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _note=self.note
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"appointment_id={_appointment_id!s}, "
            f"note={_note!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientAccountBalancesRequest(object):
    """Implementation of the 'GetClientAccountBalancesRequest' model.

    Attributes:
        balance_date (datetime): The date you want a balance relative to.   Default:
            **the current date**
        class_id (int): The class ID of the event for which you want a balance.
        client_ids (List[str]): The list of clients IDs for which you want account
            balances.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_ids": "ClientIds",
        "balance_date": "BalanceDate",
        "class_id": "ClassId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "balance_date",
        "class_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        client_ids=None,
        balance_date=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClientAccountBalancesRequest instance."""
        # Initialize members of the class
        if balance_date is not APIHelper.SKIP:
            self.balance_date =\
                 APIHelper.apply_datetime_converter(
                balance_date, APIHelper.RFC3339DateTime)\
                 if balance_date else None
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        self.client_ids = client_ids
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_ids =\
            dictionary.get("ClientIds")\
            if dictionary.get("ClientIds")\
                else None
        balance_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("BalanceDate")).datetime\
            if dictionary.get("BalanceDate") else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_ids,
                   balance_date,
                   class_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _balance_date=(
            self.balance_date
            if hasattr(self, "balance_date")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _client_ids=self.client_ids
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"balance_date={_balance_date!r}, "
            f"class_id={_class_id!r}, "
            f"client_ids={_client_ids!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _balance_date=(
            self.balance_date
            if hasattr(self, "balance_date")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _client_ids=self.client_ids
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"balance_date={_balance_date!s}, "
            f"class_id={_class_id!s}, "
            f"client_ids={_client_ids!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class Resource1(object):
    """Implementation of the 'Resource1' model.

    Attributes:
        id (int): The model property of type int.
        name (str): The model property of type str.
        location_id (int): The model property of type int.
        is_active (bool): The model property of type bool.
        schedule_types (List[ScheduleType4Enum]): The model property of type
            List[ScheduleType4Enum].
        program_ids (List[int]): The model property of type List[int].
        session_type_ids (List[int]): The model property of type List[int].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "location_id": "LocationId",
        "is_active": "IsActive",
        "schedule_types": "ScheduleTypes",
        "program_ids": "ProgramIds",
        "session_type_ids": "SessionTypeIds",
    }

    _optionals = [
        "id",
        "name",
        "location_id",
        "is_active",
        "schedule_types",
        "program_ids",
        "session_type_ids",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        is_active=APIHelper.SKIP,
        schedule_types=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        session_type_ids=APIHelper.SKIP):
        """Initialize a Resource1 instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if is_active is not APIHelper.SKIP:
            self.is_active = is_active
        if schedule_types is not APIHelper.SKIP:
            self.schedule_types = schedule_types
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if session_type_ids is not APIHelper.SKIP:
            self.session_type_ids = session_type_ids

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        is_active =\
            dictionary.get("IsActive")\
            if "IsActive" in dictionary.keys()\
                else APIHelper.SKIP
        schedule_types =\
            dictionary.get("ScheduleTypes")\
            if dictionary.get("ScheduleTypes")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        session_type_ids =\
            dictionary.get("SessionTypeIds")\
            if dictionary.get("SessionTypeIds")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   location_id,
                   is_active,
                   schedule_types,
                   program_ids,
                   session_type_ids)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _is_active=(
            self.is_active
            if hasattr(self, "is_active")
            else None
        )
        _schedule_types=(
            self.schedule_types
            if hasattr(self, "schedule_types")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"location_id={_location_id!r}, "
            f"is_active={_is_active!r}, "
            f"schedule_types={_schedule_types!r}, "
            f"program_ids={_program_ids!r}, "
            f"session_type_ids={_session_type_ids!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _is_active=(
            self.is_active
            if hasattr(self, "is_active")
            else None
        )
        _schedule_types=(
            self.schedule_types
            if hasattr(self, "schedule_types")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"location_id={_location_id!s}, "
            f"is_active={_is_active!s}, "
            f"schedule_types={_schedule_types!s}, "
            f"program_ids={_program_ids!s}, "
            f"session_type_ids={_session_type_ids!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClassesRequest(object):
    """Implementation of the 'GetClassesRequest' model.

    Attributes:
        class_description_ids (List[int]): The requested class description IDs.
        class_ids (List[int]): The requested class IDs.
        class_schedule_ids (List[int]): The requested classSchedule Ids.
        staff_ids (List[int]): The requested IDs of the teaching staff members.
        start_date_time (datetime): The requested start date for filtering. This also
            determines what you will see for the ‘BookingWindow’ StartDateTime in the
            response. For example, if you pass a StartDateTime that is on OR before
            the BookingWindow ‘Open’ days of the class, you will retrieve the actual
            ‘StartDateTime’ for the Booking Window. If you pass a StartDateTime that
            is after the BookingWindow ‘date’, then you will receive results based on
            that start date.  NOTE: ClassDate does not take Class Time into
            consideration.
        end_date_time (datetime): The requested end date for filtering.  NOTE:
            ClassDate does not take Class Time into consideration.  <br />Default:
            **today’s date**
        client_id (str): The client ID of the client who is viewing this class list.
            Based on identity, the client may be able to see additional information,
            such as membership specials.
        unique_client_id (int): The unique ID of the client who is viewing this class
            list. Based on identity, the client may be able to see additional
            information, such as membership specials.  Note: you need to provide the
            'UniqueClientId' OR the 'ClientId'. If both are provided, the
            'UniqueClientId' takes precedence.
        program_ids (List[int]): A list of program IDs on which to base the search.
        session_type_ids (List[int]): A list of session type IDs on which to base the
            search.
        location_ids (List[int]): A list of location IDs on which to base the search.
        semester_ids (List[int]): A list of semester IDs on which to base the search.
        hide_canceled_classes (bool): When `true`, canceled classes are removed from
            the response.<br />  When `false`, canceled classes are included in the
            response.<br />  Default: **false**
        scheduling_window (bool): When `true`, classes outside scheduling window are
            removed from the response.<br />  When `false`, classes are included in
            the response, regardless of the scheduling window.<br />  Default:
            **false**
        last_modified_date (datetime): When included in the request, only records
            modified on or after the `LastModifiedDate` specified are included in the
            response.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_description_ids": "ClassDescriptionIds",
        "class_ids": "ClassIds",
        "class_schedule_ids": "ClassScheduleIds",
        "staff_ids": "StaffIds",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "program_ids": "ProgramIds",
        "session_type_ids": "SessionTypeIds",
        "location_ids": "LocationIds",
        "semester_ids": "SemesterIds",
        "hide_canceled_classes": "HideCanceledClasses",
        "scheduling_window": "SchedulingWindow",
        "last_modified_date": "LastModifiedDate",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "class_description_ids",
        "class_ids",
        "class_schedule_ids",
        "staff_ids",
        "start_date_time",
        "end_date_time",
        "client_id",
        "unique_client_id",
        "program_ids",
        "session_type_ids",
        "location_ids",
        "semester_ids",
        "hide_canceled_classes",
        "scheduling_window",
        "last_modified_date",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        class_description_ids=APIHelper.SKIP,
        class_ids=APIHelper.SKIP,
        class_schedule_ids=APIHelper.SKIP,
        staff_ids=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        session_type_ids=APIHelper.SKIP,
        location_ids=APIHelper.SKIP,
        semester_ids=APIHelper.SKIP,
        hide_canceled_classes=APIHelper.SKIP,
        scheduling_window=APIHelper.SKIP,
        last_modified_date=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClassesRequest instance."""
        # Initialize members of the class
        if class_description_ids is not APIHelper.SKIP:
            self.class_description_ids = class_description_ids
        if class_ids is not APIHelper.SKIP:
            self.class_ids = class_ids
        if class_schedule_ids is not APIHelper.SKIP:
            self.class_schedule_ids = class_schedule_ids
        if staff_ids is not APIHelper.SKIP:
            self.staff_ids = staff_ids
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if session_type_ids is not APIHelper.SKIP:
            self.session_type_ids = session_type_ids
        if location_ids is not APIHelper.SKIP:
            self.location_ids = location_ids
        if semester_ids is not APIHelper.SKIP:
            self.semester_ids = semester_ids
        if hide_canceled_classes is not APIHelper.SKIP:
            self.hide_canceled_classes = hide_canceled_classes
        if scheduling_window is not APIHelper.SKIP:
            self.scheduling_window = scheduling_window
        if last_modified_date is not APIHelper.SKIP:
            self.last_modified_date =\
                 APIHelper.apply_datetime_converter(
                last_modified_date, APIHelper.RFC3339DateTime)\
                 if last_modified_date else None
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_description_ids =\
            dictionary.get("ClassDescriptionIds")\
            if dictionary.get("ClassDescriptionIds")\
                else APIHelper.SKIP
        class_ids =\
            dictionary.get("ClassIds")\
            if dictionary.get("ClassIds")\
                else APIHelper.SKIP
        class_schedule_ids =\
            dictionary.get("ClassScheduleIds")\
            if dictionary.get("ClassScheduleIds")\
                else APIHelper.SKIP
        staff_ids =\
            dictionary.get("StaffIds")\
            if dictionary.get("StaffIds")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        session_type_ids =\
            dictionary.get("SessionTypeIds")\
            if dictionary.get("SessionTypeIds")\
                else APIHelper.SKIP
        location_ids =\
            dictionary.get("LocationIds")\
            if dictionary.get("LocationIds")\
                else APIHelper.SKIP
        semester_ids =\
            dictionary.get("SemesterIds")\
            if dictionary.get("SemesterIds")\
                else APIHelper.SKIP
        hide_canceled_classes =\
            dictionary.get("HideCanceledClasses")\
            if "HideCanceledClasses" in dictionary.keys()\
                else APIHelper.SKIP
        scheduling_window =\
            dictionary.get("SchedulingWindow")\
            if "SchedulingWindow" in dictionary.keys()\
                else APIHelper.SKIP
        last_modified_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDate")).datetime\
            if dictionary.get("LastModifiedDate") else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_description_ids,
                   class_ids,
                   class_schedule_ids,
                   staff_ids,
                   start_date_time,
                   end_date_time,
                   client_id,
                   unique_client_id,
                   program_ids,
                   session_type_ids,
                   location_ids,
                   semester_ids,
                   hide_canceled_classes,
                   scheduling_window,
                   last_modified_date,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_description_ids=(
            self.class_description_ids
            if hasattr(self, "class_description_ids")
            else None
        )
        _class_ids=(
            self.class_ids
            if hasattr(self, "class_ids")
            else None
        )
        _class_schedule_ids=(
            self.class_schedule_ids
            if hasattr(self, "class_schedule_ids")
            else None
        )
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _semester_ids=(
            self.semester_ids
            if hasattr(self, "semester_ids")
            else None
        )
        _hide_canceled_classes=(
            self.hide_canceled_classes
            if hasattr(self, "hide_canceled_classes")
            else None
        )
        _scheduling_window=(
            self.scheduling_window
            if hasattr(self, "scheduling_window")
            else None
        )
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_description_ids={_class_description_ids!r}, "
            f"class_ids={_class_ids!r}, "
            f"class_schedule_ids={_class_schedule_ids!r}, "
            f"staff_ids={_staff_ids!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"program_ids={_program_ids!r}, "
            f"session_type_ids={_session_type_ids!r}, "
            f"location_ids={_location_ids!r}, "
            f"semester_ids={_semester_ids!r}, "
            f"hide_canceled_classes={_hide_canceled_classes!r}, "
            f"scheduling_window={_scheduling_window!r}, "
            f"last_modified_date={_last_modified_date!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_description_ids=(
            self.class_description_ids
            if hasattr(self, "class_description_ids")
            else None
        )
        _class_ids=(
            self.class_ids
            if hasattr(self, "class_ids")
            else None
        )
        _class_schedule_ids=(
            self.class_schedule_ids
            if hasattr(self, "class_schedule_ids")
            else None
        )
        _staff_ids=(
            self.staff_ids
            if hasattr(self, "staff_ids")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _location_ids=(
            self.location_ids
            if hasattr(self, "location_ids")
            else None
        )
        _semester_ids=(
            self.semester_ids
            if hasattr(self, "semester_ids")
            else None
        )
        _hide_canceled_classes=(
            self.hide_canceled_classes
            if hasattr(self, "hide_canceled_classes")
            else None
        )
        _scheduling_window=(
            self.scheduling_window
            if hasattr(self, "scheduling_window")
            else None
        )
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_description_ids={_class_description_ids!s}, "
            f"class_ids={_class_ids!s}, "
            f"class_schedule_ids={_class_schedule_ids!s}, "
            f"staff_ids={_staff_ids!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"program_ids={_program_ids!s}, "
            f"session_type_ids={_session_type_ids!s}, "
            f"location_ids={_location_ids!s}, "
            f"semester_ids={_semester_ids!s}, "
            f"hide_canceled_classes={_hide_canceled_classes!s}, "
            f"scheduling_window={_scheduling_window!s}, "
            f"last_modified_date={_last_modified_date!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetSitesRequest(object):
    """Implementation of the 'GetSitesRequest' model.

    Attributes:
        site_ids (List[int]): List of the requested site IDs. When omitted, returns
            all sites that the source has access to.
        include_lead_channels (bool): This is an optional parameter to get lead
            channels for a Site.
        include_per_staff_pricing (bool): Include whether or not studios have per
            staff pricing enabled.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "site_ids": "SiteIds",
        "include_lead_channels": "IncludeLeadChannels",
        "include_per_staff_pricing": "IncludePerStaffPricing",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "site_ids",
        "include_lead_channels",
        "include_per_staff_pricing",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        site_ids=APIHelper.SKIP,
        include_lead_channels=APIHelper.SKIP,
        include_per_staff_pricing=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetSitesRequest instance."""
        # Initialize members of the class
        if site_ids is not APIHelper.SKIP:
            self.site_ids = site_ids
        if include_lead_channels is not APIHelper.SKIP:
            self.include_lead_channels = include_lead_channels
        if include_per_staff_pricing is not APIHelper.SKIP:
            self.include_per_staff_pricing = include_per_staff_pricing
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        site_ids =\
            dictionary.get("SiteIds")\
            if dictionary.get("SiteIds")\
                else APIHelper.SKIP
        include_lead_channels =\
            dictionary.get("IncludeLeadChannels")\
            if "IncludeLeadChannels" in dictionary.keys()\
                else APIHelper.SKIP
        include_per_staff_pricing =\
            dictionary.get("IncludePerStaffPricing")\
            if "IncludePerStaffPricing" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(site_ids,
                   include_lead_channels,
                   include_per_staff_pricing,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _site_ids=(
            self.site_ids
            if hasattr(self, "site_ids")
            else None
        )
        _include_lead_channels=(
            self.include_lead_channels
            if hasattr(self, "include_lead_channels")
            else None
        )
        _include_per_staff_pricing=(
            self.include_per_staff_pricing
            if hasattr(self, "include_per_staff_pricing")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"site_ids={_site_ids!r}, "
            f"include_lead_channels={_include_lead_channels!r}, "
            f"include_per_staff_pricing={_include_per_staff_pricing!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _site_ids=(
            self.site_ids
            if hasattr(self, "site_ids")
            else None
        )
        _include_lead_channels=(
            self.include_lead_channels
            if hasattr(self, "include_lead_channels")
            else None
        )
        _include_per_staff_pricing=(
            self.include_per_staff_pricing
            if hasattr(self, "include_per_staff_pricing")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"site_ids={_site_ids!s}, "
            f"include_lead_channels={_include_lead_channels!s}, "
            f"include_per_staff_pricing={_include_per_staff_pricing!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddAppointmentAddOnRequest(object):
    """Implementation of the 'AddAppointmentAddOnRequest' model.

    Creates an add-on for an appointment

    Attributes:
        apply_payment (bool): When `true`, indicates that a payment should be applied
            to the appointment. Currently only ApplyPayment=false is implemented.
            Default: **true**
        appointment_id (int): The appointment ID the add-on is getting added to.
        session_type_id (int): The session type associated with the new appointment
            add-on.
        staff_id (int): The ID of the staff member who is adding the new appointment
            add-on.  Default: staff member performing the appointment.
        test (bool): When `true`, indicates that the method is to be validated, but
            no new appointment add-on data is added.  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "apply_payment": "ApplyPayment",
        "appointment_id": "AppointmentId",
        "session_type_id": "SessionTypeId",
        "staff_id": "StaffId",
        "test": "Test",
    }

    _optionals = [
        "apply_payment",
        "appointment_id",
        "session_type_id",
        "staff_id",
        "test",
    ]

    def __init__(
        self,
        apply_payment=APIHelper.SKIP,
        appointment_id=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        test=APIHelper.SKIP):
        """Initialize a AddAppointmentAddOnRequest instance."""
        # Initialize members of the class
        if apply_payment is not APIHelper.SKIP:
            self.apply_payment = apply_payment
        if appointment_id is not APIHelper.SKIP:
            self.appointment_id = appointment_id
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        apply_payment =\
            dictionary.get("ApplyPayment")\
            if "ApplyPayment" in dictionary.keys()\
                else APIHelper.SKIP
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(apply_payment,
                   appointment_id,
                   session_type_id,
                   staff_id,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _apply_payment=(
            self.apply_payment
            if hasattr(self, "apply_payment")
            else None
        )
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"apply_payment={_apply_payment!r}, "
            f"appointment_id={_appointment_id!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _apply_payment=(
            self.apply_payment
            if hasattr(self, "apply_payment")
            else None
        )
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"apply_payment={_apply_payment!s}, "
            f"appointment_id={_appointment_id!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class AddAppointmentRequest(object):
    """Implementation of the 'AddAppointmentRequest' model.

    Represents a request to add a new appointment, including details such as client
    information, appointment timing, location, and additional preferences.

    Attributes:
        apply_payment (bool): When `true`, indicates that a payment should be applied
            to the appointment.   <br />Default: **true**
        client_id (str): The RRSID of the client for whom the new appointment is
            being made.
        duration (int): The duration of the appointment. This parameter is used to
            change the default duration of an appointment.
        execute (str): The action taken to add this appointment. Possible values are:
            confirm, unconfirm, arrive, unarrive, cancel, latecancel, complete.
        end_date_time (datetime): The end date and time of the new appointment. <br
            />  Default: **StartDateTime**, offset by the staff member’s default
            appointment duration.
        gender_preference (str): The client’s service provider gender preference.
        location_id (int): The ID of the location where the new appointment is to
            take place.
        notes (str): Any general notes about this appointment.
        provider_id (str): If a user has Complementary and Alternative Medicine
            features enabled, this parameter assigns a provider ID to the appointment.
        resource_ids (List[int]): A list of resource IDs to associate with the new
            appointment.
        send_email (bool): Whether to send client an email for cancellations. An
            email is sent only if the client has an email address and automatic
            emails have been set up.   <br />Default: **false**
        session_type_id (int): The session type associated with the new appointment.
        staff_id (int): The ID of the staff member who is adding the new appointment.
        staff_requested (bool): When `true`, indicates that the staff member was
            requested specifically by the client.
        start_date_time (datetime): The start date and time of the new appointment.
        test (bool): When true, indicates that the method is to be validated, but no
            new appointment data is added.   <br />Default: **false**
        is_waitlist (bool): When `true`, indicates that the client should be added to
            a specific appointment waiting list.  When `false`, the client should not
            be added to the waiting list.  Default: **false**
        is_request (bool): Indicates whether to add an appointment request for
            review.  If `true`, the appointment will be added as a request, bypassing
            the `IsWaitlist` parameter and two validations:  1. If a consumer is
            adding the appointment for another person.  2. If a staff member without
            permission to add appointments for other staff members is adding the
            appointment for another staff member.    This also allows anonymous calls
            (without an authentication token) to this endpoint.  The
            `AllowClientsToBookAppointments` option must be disabled. If it is
            enabled and the `IsRequest` parameter is `true`, it will return an error.
            For the appointment to be created as a request, one of the following
            conditions must also be met:  - The call is anonymous (no authentication
            token provided).  - The call is authenticated with a consumer token.  -
            The authenticated user lacks permission to book appointments for other
            staff (`BookAppointmentsForAllStaff`) and is attempting to book for a
            different staff member.    - In this last case, if the `IsRequest`
            parameter is `true` and the authenticated user has the
            `BookAppointmentsForAllStaff` permission or is attempting to book the
            appointment for themselves,    the appointment will be created, but not
            as an appointment request.    If `false`, the appointment will follow the
            standard creation process, respecting the `IsWaitlist` parameter.
            Default: `false`
        partner_external_id (str): Optional external key for api partners.
        add_appointment_request_id (int): A unique identifier for tracking the
            AddAppointmentRequest. This ID is not stored and is used to match each
            request with its corresponding response.  The request object will also be
            returned in the response, with the same ID value.  - For single requests,
            this value will be ignored.  - For multiple requests, if no value is
            provided, the system will generate an identifier ranging from 0 to
            (number of requests - 1).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "location_id": "LocationId",
        "session_type_id": "SessionTypeId",
        "staff_id": "StaffId",
        "start_date_time": "StartDateTime",
        "apply_payment": "ApplyPayment",
        "duration": "Duration",
        "execute": "Execute",
        "end_date_time": "EndDateTime",
        "gender_preference": "GenderPreference",
        "notes": "Notes",
        "provider_id": "ProviderId",
        "resource_ids": "ResourceIds",
        "send_email": "SendEmail",
        "staff_requested": "StaffRequested",
        "test": "Test",
        "is_waitlist": "IsWaitlist",
        "is_request": "IsRequest",
        "partner_external_id": "PartnerExternalId",
        "add_appointment_request_id": "AddAppointmentRequestId",
    }

    _optionals = [
        "apply_payment",
        "duration",
        "execute",
        "end_date_time",
        "gender_preference",
        "notes",
        "provider_id",
        "resource_ids",
        "send_email",
        "staff_requested",
        "test",
        "is_waitlist",
        "is_request",
        "partner_external_id",
        "add_appointment_request_id",
    ]

    def __init__(
        self,
        client_id=None,
        location_id=None,
        session_type_id=None,
        staff_id=None,
        start_date_time=None,
        apply_payment=APIHelper.SKIP,
        duration=APIHelper.SKIP,
        execute=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        gender_preference=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        provider_id=APIHelper.SKIP,
        resource_ids=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        staff_requested=APIHelper.SKIP,
        test=APIHelper.SKIP,
        is_waitlist=APIHelper.SKIP,
        is_request=APIHelper.SKIP,
        partner_external_id=APIHelper.SKIP,
        add_appointment_request_id=APIHelper.SKIP):
        """Initialize a AddAppointmentRequest instance."""
        # Initialize members of the class
        if apply_payment is not APIHelper.SKIP:
            self.apply_payment = apply_payment
        self.client_id = client_id
        if duration is not APIHelper.SKIP:
            self.duration = duration
        if execute is not APIHelper.SKIP:
            self.execute = execute
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if gender_preference is not APIHelper.SKIP:
            self.gender_preference = gender_preference
        self.location_id = location_id
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if provider_id is not APIHelper.SKIP:
            self.provider_id = provider_id
        if resource_ids is not APIHelper.SKIP:
            self.resource_ids = resource_ids
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        self.session_type_id = session_type_id
        self.staff_id = staff_id
        if staff_requested is not APIHelper.SKIP:
            self.staff_requested = staff_requested
        self.start_date_time =\
             APIHelper.apply_datetime_converter(
            start_date_time, APIHelper.RFC3339DateTime)\
             if start_date_time else None
        if test is not APIHelper.SKIP:
            self.test = test
        if is_waitlist is not APIHelper.SKIP:
            self.is_waitlist = is_waitlist
        if is_request is not APIHelper.SKIP:
            self.is_request = is_request
        if partner_external_id is not APIHelper.SKIP:
            self.partner_external_id = partner_external_id
        if add_appointment_request_id is not APIHelper.SKIP:
            self.add_appointment_request_id = add_appointment_request_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else None
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else None
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else None
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else None
        apply_payment =\
            dictionary.get("ApplyPayment")\
            if "ApplyPayment" in dictionary.keys()\
                else APIHelper.SKIP
        duration =\
            dictionary.get("Duration")\
            if dictionary.get("Duration")\
                else APIHelper.SKIP
        execute =\
            dictionary.get("Execute")\
            if dictionary.get("Execute")\
                else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        gender_preference =\
            dictionary.get("GenderPreference")\
            if dictionary.get("GenderPreference")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        provider_id =\
            dictionary.get("ProviderId")\
            if dictionary.get("ProviderId")\
                else APIHelper.SKIP
        resource_ids =\
            dictionary.get("ResourceIds")\
            if dictionary.get("ResourceIds")\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        staff_requested =\
            dictionary.get("StaffRequested")\
            if "StaffRequested" in dictionary.keys()\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        is_waitlist =\
            dictionary.get("IsWaitlist")\
            if "IsWaitlist" in dictionary.keys()\
                else APIHelper.SKIP
        is_request =\
            dictionary.get("IsRequest")\
            if "IsRequest" in dictionary.keys()\
                else APIHelper.SKIP
        partner_external_id =\
            dictionary.get("PartnerExternalId")\
            if dictionary.get("PartnerExternalId")\
                else APIHelper.SKIP
        add_appointment_request_id =\
            dictionary.get("AddAppointmentRequestId")\
            if dictionary.get("AddAppointmentRequestId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   location_id,
                   session_type_id,
                   staff_id,
                   start_date_time,
                   apply_payment,
                   duration,
                   execute,
                   end_date_time,
                   gender_preference,
                   notes,
                   provider_id,
                   resource_ids,
                   send_email,
                   staff_requested,
                   test,
                   is_waitlist,
                   is_request,
                   partner_external_id,
                   add_appointment_request_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _apply_payment=(
            self.apply_payment
            if hasattr(self, "apply_payment")
            else None
        )
        _client_id=self.client_id
        _duration=(
            self.duration
            if hasattr(self, "duration")
            else None
        )
        _execute=(
            self.execute
            if hasattr(self, "execute")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _gender_preference=(
            self.gender_preference
            if hasattr(self, "gender_preference")
            else None
        )
        _location_id=self.location_id
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        _resource_ids=(
            self.resource_ids
            if hasattr(self, "resource_ids")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _session_type_id=self.session_type_id
        _staff_id=self.staff_id
        _staff_requested=(
            self.staff_requested
            if hasattr(self, "staff_requested")
            else None
        )
        _start_date_time=self.start_date_time
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _is_waitlist=(
            self.is_waitlist
            if hasattr(self, "is_waitlist")
            else None
        )
        _is_request=(
            self.is_request
            if hasattr(self, "is_request")
            else None
        )
        _partner_external_id=(
            self.partner_external_id
            if hasattr(self, "partner_external_id")
            else None
        )
        _add_appointment_request_id=(
            self.add_appointment_request_id
            if hasattr(self, "add_appointment_request_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"apply_payment={_apply_payment!r}, "
            f"client_id={_client_id!r}, "
            f"duration={_duration!r}, "
            f"execute={_execute!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"gender_preference={_gender_preference!r}, "
            f"location_id={_location_id!r}, "
            f"notes={_notes!r}, "
            f"provider_id={_provider_id!r}, "
            f"resource_ids={_resource_ids!r}, "
            f"send_email={_send_email!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"staff_requested={_staff_requested!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"test={_test!r}, "
            f"is_waitlist={_is_waitlist!r}, "
            f"is_request={_is_request!r}, "
            f"partner_external_id={_partner_external_id!r}, "
            f"add_appointment_request_id={_add_appointment_request_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _apply_payment=(
            self.apply_payment
            if hasattr(self, "apply_payment")
            else None
        )
        _client_id=self.client_id
        _duration=(
            self.duration
            if hasattr(self, "duration")
            else None
        )
        _execute=(
            self.execute
            if hasattr(self, "execute")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _gender_preference=(
            self.gender_preference
            if hasattr(self, "gender_preference")
            else None
        )
        _location_id=self.location_id
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        _resource_ids=(
            self.resource_ids
            if hasattr(self, "resource_ids")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _session_type_id=self.session_type_id
        _staff_id=self.staff_id
        _staff_requested=(
            self.staff_requested
            if hasattr(self, "staff_requested")
            else None
        )
        _start_date_time=self.start_date_time
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _is_waitlist=(
            self.is_waitlist
            if hasattr(self, "is_waitlist")
            else None
        )
        _is_request=(
            self.is_request
            if hasattr(self, "is_request")
            else None
        )
        _partner_external_id=(
            self.partner_external_id
            if hasattr(self, "partner_external_id")
            else None
        )
        _add_appointment_request_id=(
            self.add_appointment_request_id
            if hasattr(self, "add_appointment_request_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"apply_payment={_apply_payment!s}, "
            f"client_id={_client_id!s}, "
            f"duration={_duration!s}, "
            f"execute={_execute!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"gender_preference={_gender_preference!s}, "
            f"location_id={_location_id!s}, "
            f"notes={_notes!s}, "
            f"provider_id={_provider_id!s}, "
            f"resource_ids={_resource_ids!s}, "
            f"send_email={_send_email!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"staff_requested={_staff_requested!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"test={_test!s}, "
            f"is_waitlist={_is_waitlist!s}, "
            f"is_request={_is_request!s}, "
            f"partner_external_id={_partner_external_id!s}, "
            f"add_appointment_request_id={_add_appointment_request_id!s}, "
            f")"
        )
